@@ -1,18 +1,17 @@
-from typing import Any, Optional, Dict, List
+from typing import Any, Optional, Dict, List, Protocol
 
 from starlette.applications import Starlette
 from starlette.responses import JSONResponse
 from starlette.routing import Route, Mount
 from starlette.middleware import Middleware
 from starlette.types import ASGIApp
-from aioprometheus import Service as PromService
 
 from .route_def import make_route_def
 from .endpoint import make_endpoint
 from .errors import JSONErrorMiddleware
 from .auth import AuthBackend, AuthMiddleware
 from .security import CORSConfig, permissive_cors_config, cors_middleware_from_config
-from .metrics import MetricsMiddleware, _metrics_sync_init
+from .metrics import MetricsMiddleware, MetricsRegistry
 from .openapi import openapi_app
 
 def create_app(
@@ -29,15 +28,15 @@ def create_app(
 	method_prefixes = tuple([ m + '_' for m in http_methods ])
 	route_defs = [ make_route_def(getattr(srv, m)) for m in dir(srv) if m in http_methods or m.startswith(method_prefixes) ]
 
-	metrics_svc = PromService()
-	_metrics_sync_init(
-		metrics_svc,
-		app = name,
-	)
+	metrics_registry = getattr(srv, 'metrics', None)
+	if not metrics_registry or not isinstance(metrics_registry, MetricsRegistry):
+		metrics_registry = MetricsRegistry()
+
+	metrics_registry._const_labels['app'] = name
 
 	async def metrics_async_init() -> None:
 		if metrics_port:
-			await metrics_svc.start(addr = '0.0.0.0', port = metrics_port)
+			await metrics_registry._prom_svc.start(addr = '0.0.0.0', port = metrics_port)
 
 	startup_funcs = [ metrics_async_init ]
 	shutdown_funcs = []
@@ -47,12 +46,12 @@ def create_app(
 			startup_funcs.append(startup_func)
 		if shutdown_func := getattr(obj, 'shutdown', None):
 			shutdown_funcs.append(shutdown_func)
-	
+
 	_attach_lifecyle_methods(srv)
 
 	middleware = [ Middleware(JSONErrorMiddleware) ]
 	if auth_backend:
-		middleware.append(Middleware(AuthMiddleware, auth_backend = auth_backend))
+		middleware.append(Middleware(AuthMiddleware, auth_backend = auth_backend, metrics_registry = metrics_registry))
 		_attach_lifecyle_methods(auth_backend)
 
 	core_app = Starlette(
@@ -78,7 +77,7 @@ def create_app(
 		on_startup = startup_funcs,
 		on_shutdown = shutdown_funcs,
 		middleware = [
-			Middleware(MetricsMiddleware),
+			Middleware(MetricsMiddleware, metrics_registry = metrics_registry),
 			cors_middleware_from_config(cors_config),
 		],
 	)
