@@ -1,6 +1,6 @@
 from typing import Any, Union, Dict, Callable, Literal, Set, TypeVar
 from dataclasses import dataclass
-from datetime import datetime
+from datetime import datetime, date
 
 from .errors import BadRequest
 from .auth import Principal
@@ -26,6 +26,7 @@ def _parse_bool(x: str) -> bool:
 _parser_overrides: Dict[type, _ParserType] = {
 	bool: _parse_bool,
 	datetime: datetime.fromisoformat,
+	date: date.fromisoformat,
 }
 
 T = TypeVar('T')
@@ -74,6 +75,8 @@ class RouteDef:
 	args: Dict[str, ArgDef]
 	return_type: type
 	requires_principal: bool
+	readable_name: str
+	doc: str
 
 def make_route_def(impl: Callable[..., Any]) -> RouteDef:
 	name_tokens = impl.__name__.split('_')
@@ -102,4 +105,6 @@ def make_route_def(impl: Callable[..., Any]) -> RouteDef:
 		args = args,
 		return_type = return_type,
 		requires_principal = requires_principal,
+		readable_name = ' '.join([ s.title() for s in name_tokens[1:] ]),
+		doc = getattr(impl, '__doc__'),
 	)
